@@ -123,7 +123,7 @@ class Runtime(ProcessStreams, ProcessCreation):
         dump.update(timeout=self.timeout)
         dump.update(timed_out=self.timed_out)
         dump.update(raised_exception=self.raised_exception)
-        dump.update(exception=self.exception)
+        dump.update(exception=self.exception.dump() if self.exception is not None else None)
         return dump
 
 
@@ -311,7 +311,7 @@ def run(*args: str, stdin: bytes = None, timeout: float = None, cwd: Path = None
     """
 
     if timeout is None:
-        log.warning(f"process.run has been invoked without a timeout from {get_source_location()}")
+        log.warning(f"process.run has been invoked without a timeout from {get_source_location(2)}")
 
     # Spawn the process, access stdout and stderr
     try:
